import request from '@/config/axios'

// 磁盘监控日志 VO
export interface MonitorDiskVO {
  id: number // 访问ID
  hostName: string // 主机名称
  hostIp: string // 服务器ip
  disk: string // 盘符
  diskName: string // 磁盘名
  spaceTotal: number // 总空间
  spaceUsed: number // 已用空间
  spaceUsable: number // 可用空间
  spaceRatio: number // 空间使用比例
}

// 磁盘监控日志 API
export const MonitorDiskApi = {
  // 查询磁盘监控日志分页
  getMonitorDiskPage: async (params: any) => {
    return await request.get({ url: `/infra/monitor-disk/page`, params })
  },

  // 查询磁盘监控日志列表
  getMonitorDiskList: async (params: any) => {
    return await request.get({ url: `/infra/monitor-disk/getMonitorDiskList`, params })
  },

  // 查询主机列表
  getAllHost: async () => {
    return await request.get({ url: `/infra/monitor-disk/getAllHost`})
  },

  // 查询ip列表
  getAllIp: async () => {
    return await request.get({ url: `/infra/monitor-disk/getAllIp`})
  },

  // 查询磁盘监控日志信息
  getMonitorDiskInfo: async (params: any) => {
    return await request.get({ url: `/infra/monitor-disk/getMonitorDiskInfo`, params })
  },

  // 查询磁盘监控日志详情
  getMonitorDisk: async (id: number) => {
    return await request.get({ url: `/infra/monitor-disk/get?id=` + id })
  },

  // 新增磁盘监控日志
  createMonitorDisk: async (data: MonitorDiskVO) => {
    return await request.post({ url: `/infra/monitor-disk/create`, data })
  },

  // 修改磁盘监控日志
  updateMonitorDisk: async (data: MonitorDiskVO) => {
    return await request.put({ url: `/infra/monitor-disk/update`, data })
  },

  // 删除磁盘监控日志
  deleteMonitorDisk: async (id: number) => {
    return await request.delete({ url: `/infra/monitor-disk/delete?id=` + id })
  },

  // 导出磁盘监控日志 Excel
  exportMonitorDisk: async (params) => {
    return await request.download({ url: `/infra/monitor-disk/export-excel`, params })
  },
}
